summaryrefslogtreecommitdiff
path: root/src/mongo/db/index_builds_coordinator.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/index_builds_coordinator.h')
-rw-r--r--src/mongo/db/index_builds_coordinator.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/mongo/db/index_builds_coordinator.h b/src/mongo/db/index_builds_coordinator.h
index 56df844a0e5..c78134998db 100644
--- a/src/mongo/db/index_builds_coordinator.h
+++ b/src/mongo/db/index_builds_coordinator.h
@@ -46,6 +46,7 @@
#include "mongo/db/rebuild_indexes.h"
#include "mongo/db/repl/oplog_entry.h"
#include "mongo/db/repl_index_build_state.h"
+#include "mongo/db/resumable_index_builds_gen.h"
#include "mongo/db/storage/durable_catalog.h"
#include "mongo/executor/task_executor.h"
#include "mongo/executor/thread_pool_task_executor.h"
@@ -146,11 +147,13 @@ public:
IndexBuildOptions indexBuildOptions) = 0;
/**
* Given a set of two-phase index builds, start, but do not complete each one in a background
* thread. Each index build will wait for a replicated commit or abort, as in steady-state
* replication.
*/
- void restartIndexBuildsForRecovery(OperationContext* opCtx, const IndexBuilds& buildsToRestart);
+ void restartIndexBuildsForRecovery(OperationContext* opCtx,
+ const IndexBuilds& buildsToRestart,
+ const std::vector<ResumeIndexInfo>& buildsToResume);
/**
* Runs the full index rebuild for recovery. This will only rebuild single-phase index builds.
@@ -146,11 +147,13 @@ public:
IndexBuildOptions indexBuildOptions) = 0;
/**
- * Given a set of two-phase index builds, start, but do not complete each one in a background
- * thread. Each index build will wait for a replicated commit or abort, as in steady-state
- * replication.
+ * Resumes and restarts index builds for recovery. Anything that fails to resume will be
+ * started in a background thread. Each index build will wait for a replicated commit or abort,
+ * as in steady-state.
*/